@@ -419,6 +419,13 @@ afs_UFSReadFast(avc, auio, acred, albn, abpp, noLock)
 	    AFS_GUNLOCK();
 	    code = osi_file_uio_rdwr(tfile, auio, UIO_READ);
 	    AFS_GLOCK();
+#else
+#if defined(AFS_DARWIN_ENV)
+            AFS_GUNLOCK();
+            VOP_LOCK(tfile->vnode, LK_EXCLUSIVE, current_proc());
+            code = VOP_READ(tfile->vnode, auio, 0, &afs_osi_cred);
+            VOP_UNLOCK(tfile->vnode, 0, current_proc());
+            AFS_GLOCK();
 #else
 	    code = VOP_RDWR(tfile->vnode, auio, UIO_READ, 0, &afs_osi_cred);
 #endif
@@ -426,6 +433,7 @@ afs_UFSReadFast(avc, auio, acred, albn, abpp, noLock)
 #endif
 #endif
 #endif
+#endif
 #endif
 	    auio->afsio_offset += avc->quick.minLoc;
 	    osi_UFSClose(tfile);
@@ -749,6 +757,13 @@ tagain:
 	    AFS_GUNLOCK();
 	    code = osi_file_uio_rdwr(tfile, &tuio, UIO_READ);
 	    AFS_GLOCK();
+#else
+#if defined(AFS_DARWIN_ENV)
+            AFS_GUNLOCK();
+            VOP_LOCK(tfile->vnode, LK_EXCLUSIVE, current_proc());
+            code = VOP_READ(tfile->vnode, &tuio, 0, &afs_osi_cred);
+            VOP_UNLOCK(tfile->vnode, 0, current_proc());
+            AFS_GLOCK();
 #else
 	    code = VOP_RDWR(tfile->vnode, &tuio, UIO_READ, 0, &afs_osi_cred);
 #endif
@@ -758,6 +773,7 @@ tagain:
 #endif
 #endif
 #endif
+#endif
 
 #ifdef IHINT
 	     if (!tdc->ihint && nihints < maxIHint) {
