@@ -17,6 +17,7 @@
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
+#define snprintf _snprintf
 #else
 #include <sys/socket.h>
 #include <netdb.h>
@@ -41,9 +42,6 @@
 #include "afs/audit.h"
 #include "kalog.h"
 
-#include "../permit_xprt.h"
-
-
 /* my kerberos error codes */
 #define KERB_ERR_BAD_MSG_TYPE  99
 #define KERB_ERR_BAD_LIFETIME  98
@@ -446,7 +444,10 @@ afs_int32 UDP_GetTicket (ksoc, pkt, kvno, authDomain, ticket, ticketLen, auth, a
       code = KERB_ERR_PKT_VER;	/* was KABADTICKET */
       goto abort;
     }
-    if (celllen == 0) strcpy (cell, lrealm);
+    if (celllen == 0) {
+	strncpy (cell, lrealm, MAXKTCREALMLEN-1);
+	cell[MAXKTCREALMLEN-1] = 0;
+    };
 
     if (krb_udp_debug) {
 	printf ("UGetTicket: got ticket from '%s'.'%s'@'%s'\n",
